==> seahub-13.0.11-1-any.pkg.tar.zst: usr/share/seafile-server/seahub/frontend/src/translate.js <==
import { gettext } from './utils/constants';

gettext('You have not shared any folders');
gettext('You don\'t have any share links');
gettext('You don\'t have any upload links');
gettext('You don\'t have any favorite items yet');
gettext('Modify');
gettext('Import Users');
gettext('No connected devices');
gettext('No sync errors');
gettext('No groups');
gettext('No notifications');
gettext('Notification Detail');
gettext('No share links');
gettext('No upload links');
gettext('No invitations');
gettext('No terms and conditions');
gettext('Tip: libraries deleted {trashReposExpireDays} days ago will be cleaned automatically.');
gettext('No favorites');
gettext('No folders shared');
gettext('No Admin login logs');
gettext('No Admin operation logs');
gettext('No permission logs');
gettext('No login logs');
gettext('No file update logs');
gettext('No file access logs');
gettext('Save Selected Items');
gettext('New view');
gettext('You have not shared any folders with other users yet. You can share a folder with other users by clicking the share icon to the right of a folder\'s name.');
gettext('You have not created any share links yet. A share link can be used to share files and folders with anyone. You can create a share link for a file or folder by clicking the share icon to the right of its name.');
gettext('You have not created any upload links yet. An upload link allows anyone to upload files to a folder or library. You can create an upload link for a folder or library by clicking the share icon to the right of its name.');
gettext('You have not added any libraries, folders or files to your favorites yet. A favorite gives you quick access to your most frequently used objects. You can add a library, folder or file to your favorites by clicking the star to the left of its name.');
gettext('No public libraries have been created yet. A public library is accessible by all users. You can create a public library by clicking the "Add Library" item in the dropdown menu.');
gettext('No libraries have been shared directly with you. A shared library can be shared with full or restricted permission. If you need access to a library owned by another user, ask the user to share the library with you.');
gettext('Group info');
gettext('Change view type');
gettext('User {user_link} has added you to {group_link}');
gettext('No user shares');
gettext('No group shares');
gettext('Face recognition is done for library {libraryName}.');

==> seahub-13.0.15-1-any.pkg.tar.zst: usr/share/seafile-server/seahub/frontend/src/translate.js <==
import { gettext } from './utils/constants';

gettext('You have not shared any folders');
gettext('You don\'t have any share links');
gettext('You don\'t have any upload links');
gettext('You don\'t have any favorite items yet');
gettext('Modify');
gettext('Import Users');
gettext('No connected devices');
gettext('No sync errors');
gettext('No groups');
gettext('No notifications');
gettext('Notification Detail');
gettext('No share links');
gettext('No upload links');
gettext('No invitations');
gettext('No terms and conditions');
gettext('Tip: libraries deleted {trashReposExpireDays} days ago will be cleaned automatically.');
gettext('No favorites');
gettext('No folders shared');
gettext('No Admin login logs');
gettext('No Admin operation logs');
gettext('No permission logs');
gettext('No login logs');
gettext('No file update logs');
gettext('No file access logs');
gettext('Save Selected Items');
gettext('New view');
gettext('You have not shared any folders with other users yet. You can share a folder with other users by clicking the share icon to the right of a folder\'s name.');
gettext('You have not created any share links yet. A share link can be used to share files and folders with anyone. You can create a share link for a file or folder by clicking the share icon to the right of its name.');
gettext('You have not created any upload links yet. An upload link allows anyone to upload files to a folder or library. You can create an upload link for a folder or library by clicking the share icon to the right of its name.');
gettext('You have not added any libraries, folders or files to your favorites yet. A favorite gives you quick access to your most frequently used objects. You can add a library, folder or file to your favorites by clicking the star to the left of its name.');
gettext('No public libraries have been created yet. A public library is accessible by all users. You can create a public library by clicking the "Add Library" item in the dropdown menu.');
gettext('No libraries have been shared directly with you. A shared library can be shared with full or restricted permission. If you need access to a library owned by another user, ask the user to share the library with you.');
gettext('Group info');
gettext('Change view type');
gettext('User {user_link} has added you to {group_link}');
gettext('No user shares');
gettext('No group shares');
gettext('Face recognition is done for library {libraryName}.');
gettext('A folder named {upload_folder_link} is uploaded to {uploaded_link}.');
gettext('A folder named {upload_folder_link} is uploaded.');
gettext('A file named {upload_file_link} is uploaded to {uploaded_link}.');
gettext('A file named {upload_file_link} is uploaded.');
